django-happymailer |Build Status| |Coverage Status|
===================================================

Django Email Template Manager

install
-------

all docs is coming soon...

.. |Build Status| image:: https://travis-ci.org/kidig/django-happymailer.svg?branch=master
   :target: https://travis-ci.org/kidig/django-happymailer
.. |Coverage Status| image:: https://coveralls.io/repos/github/kidig/django-happymailer/badge.svg?branch=master
   :target: https://coveralls.io/github/kidig/django-happymailer?branch=master
